<?php

use EventPortal\Http\Controllers\Admin\AgendaController;
use EventPortal\Http\Controllers\Admin\Delegate\DelegateController;
use EventPortal\Http\Controllers\Admin\Email\EmailController;
use EventPortal\Http\Controllers\Admin\Email\EmailPreviewController;
use EventPortal\Http\Controllers\Admin\Event\ArchivedEventController;
use EventPortal\Http\Controllers\Admin\Event\EventController;
use EventPortal\Http\Controllers\Admin\EventDelegate\DelegatesNotOnEventController;
use EventPortal\Http\Controllers\Admin\EventDelegate\EventDelegateController;
use EventPortal\Http\Controllers\Admin\EventSpeaker\EventSpeakerController;
use EventPortal\Http\Controllers\Admin\EventSpeaker\SpeakersNotOnEventController;
use EventPortal\Http\Controllers\Admin\EventVenue\EventVenueController;
use EventPortal\Http\Controllers\Admin\EventVenue\VenuesNotOnEventController;
use EventPortal\Http\Controllers\Admin\RoleController;
use EventPortal\Http\Controllers\Admin\Speaker\SpeakerController;
use EventPortal\Http\Controllers\Admin\TeamController;
use EventPortal\Http\Controllers\Admin\VenueController;
use Illuminate\Support\Facades\Route;

Route::get('/', 'DashboardController')->name('admin.dashboard.index');

Route::group(['prefix' => 'events'], static function (): void {
    Route::group(['prefix' => '{event}/delegates'], static function (): void {
        Route::get('/add', [DelegatesNotOnEventController::class, 'index'])->name('admin.event.delegate.create');
        Route::post('/add', 'EventDelegate\AssociateToEventController')->name('admin.event.delegate.store');
        Route::post('/remove', 'EventDelegate\DisassociateFromEventController')->name('admin.event.delegate.destroy');

        Route::get('/', [EventDelegateController::class, 'index'])->name('admin.event.delegate.index');
        Route::get('{delegate}', [EventDelegateController::class, 'show'])->name('admin.event.delegate.show');
        Route::post(
            '{delegate}/transition/{type}',
            'EventDelegate\EventDelegateTransitionController'
        )->name('admin.event.delegate.transition');
    });
    Route::group(['prefix' => '{event}/speakers'], static function (): void {
        Route::get('/add', [SpeakersNotOnEventController::class, 'index'])->name('admin.event.speaker.create');
        Route::post('/add', 'EventSpeaker\AssociateToEventController')->name('admin.event.speaker.store');
        Route::post('/remove', 'EventSpeaker\DisassociateFromEventController')->name('admin.event.speaker.destroy');

        Route::get('/', [EventSpeakerController::class, 'index'])->name('admin.event.speaker.index');
        Route::get('{speaker}', [EventSpeakerController::class, 'show'])->name('admin.event.speaker.show');
    });

    Route::group(['prefix' => '{event}/venues'], static function (): void {
        Route::get('/', [EventVenueController::class, 'index'])->name('admin.event.venue.index');
        Route::get('/add', [VenuesNotOnEventController::class, '__invoke'])->name('admin.event.venue.create');
        Route::post('/add', 'EventVenue\AssociateToEventController')->name('admin.event.venue.store');
        Route::post('/remove', 'EventVenue\DisassociateFromEventController')->name('admin.event.venue.destroy');
        Route::get('{eventVenue}', [EventVenueController::class, 'show'])->name('admin.event.venue.show');
    });

    Route::get('/archived', [ArchivedEventController::class, 'index'])->name('admin.event.archived.index');

    Route::post('{event}/transition/{type}', 'Event\EventTransitionController')->name('admin.event.transition');

    Route::get('/', [EventController::class, 'index'])->name('admin.event.index');
    Route::post('/', [EventController::class, 'store'])->name('admin.event.store');

    Route::get('create', [EventController::class, 'create'])->name('admin.event.create');
    Route::prefix('{event}')->middleware('current-team')->group(static function (): void {
        Route::get('/', [EventController::class, 'show'])->name('admin.event.show');
        Route::get('/edit', [EventController::class, 'edit'])->name('admin.event.edit');
        Route::post('/update', [EventController::class, 'update'])->name('admin.event.update');
        Route::post('/delete', [EventController::class, 'delete'])->name('admin.event.delete');

        Route::post('/transition/{type}', 'Event\EventTransitionController')->name('admin.event.transition');

        Route::get('/agenda', [AgendaController::class, 'index'])->name('admin.agenda.index');
        Route::post('/agenda', [AgendaController::class, 'store'])->name('admin.agenda.store');
        Route::post('/agenda/{agenda}/delete', [AgendaController::class, 'destroy'])->name('admin.agenda.destroy');

        Route::group(['prefix' => 'emails'], function (): void {
            Route::get('/', [EmailController::class, 'index'])->name('admin.email.index');
            Route::get('{email}', [EmailController::class, 'show'])->name('admin.email.show');
            Route::get('{email}/edit', [EmailController::class, 'edit'])->name('admin.email.edit');
            Route::post('{email}/update', [EmailController::class, 'update'])->name('admin.email.update');
            Route::get('{email}/preview', [EmailPreviewController::class, 'show'])->name('admin.email.preview.show');
            Route::post('{email}/preview/send', [
                EmailPreviewController::class,
                'store',
            ])->name('admin.email.preview.store');

            Route::post('{email}/send', 'Email\SendEventEmailController')->name('admin.email.send');
        });
    });
});

Route::group(['prefix' => 'permissions'], function (): void {
    Route::get('/', 'PermissionController@index')->name('admin.permission.index');
    Route::post('/', 'PermissionController@update')->name('admin.permission.update');

    Route::get('role', [RoleController::class, 'create'])->name('admin.role.create');
    Route::post('role', [RoleController::class, 'store'])->name('admin.role.store');
});

Route::post('pathway/{pathway}/session', 'SessionController@store')->name('admin.session.store');
Route::put('session/{session}', 'SessionController@update')->name('admin.session.update');
Route::post('session/{session}/delete', 'SessionController@delete')->name('admin.session.delete');

Route::group(['prefix' => 'delegates'], function (): void {
    Route::get('/', [DelegateController::class, 'index'])->name('admin.delegate.index');
    Route::get('create', [DelegateController::class, 'create'])->name('admin.delegate.create');
    Route::post('/', [DelegateController::class, 'store'])->name('admin.delegate.store');
    Route::get('{delegate}/edit', [DelegateController::class, 'edit'])->name('admin.delegate.edit');
    Route::post('{delegate}/update', [DelegateController::class, 'update'])->name('admin.delegate.update');
    Route::get('{delegate}', [DelegateController::class, 'show'])->name('admin.delegate.show');
});

Route::group(['prefix' => 'speakers'], static function (): void {
    Route::get('/', [SpeakerController::class, 'index'])->name('admin.speaker.index');
    Route::get('create', [SpeakerController::class, 'create'])->name('admin.speaker.create');
    Route::post('/', [SpeakerController::class, 'store'])->name('admin.speaker.store');
    Route::get('{speaker}/edit', [SpeakerController::class, 'edit'])->name('admin.speaker.edit');
    Route::post('{speaker}/update', [SpeakerController::class, 'update'])->name('admin.speaker.update');
    Route::get('{speaker}', [SpeakerController::class, 'show'])->name('admin.speaker.show');
});

Route::group(['prefix' => 'venues'], function (): void {
    Route::get('/', [VenueController::class, 'index'])->name('admin.venue.index');
    Route::get('create', [VenueController::class, 'create'])->name('admin.venue.create');
    Route::post('/', [VenueController::class, 'store'])->name('admin.venue.store');
    Route::get('{venue}/edit', [VenueController::class, 'edit'])->name('admin.venue.edit');
    Route::post('{venue}/update', [VenueController::class, 'update'])->name('admin.venue.update');
    Route::get('{venue}', [VenueController::class, 'show'])->name('admin.venue.show');
});

Route::group(['prefix' => 'team'], static function (): void {
    Route::get('/', [TeamController::class, 'index'])->name('admin.team.index');
    Route::post('/', [TeamController::class, 'store'])->name('admin.team.store');
    Route::get('create', [TeamController::class, 'create'])->name('admin.team.create');
    Route::get('{team}/edit', [TeamController::class, 'edit'])->name('admin.team.edit');
    Route::post('{team}/update', [TeamController::class, 'update'])->name('admin.team.update');
    Route::post('{team}/delete', [TeamController::class, 'delete'])->name('admin.team.delete');
});

Route::group(['prefix' => 'user'], function (): void {
    Route::get('/', 'UserController@index')->name('admin.user.index');
    Route::get('create', 'UserController@create')->name('admin.user.create');
    Route::post('/', 'UserController@store')->name('admin.user.store');

    Route::prefix('{admin}')->group(function (): void {
        Route::get('/', 'UserController@show')->name('admin.user.show');
        Route::get('edit', 'UserController@edit')->name('admin.user.edit');
        Route::post('update', 'UserController@update')->name('admin.user.update');
        Route::post('delete', 'UserController@delete')->name('admin.user.delete');
    });
});
