<?php

namespace EventPortal\Tests\Feature\Admin\Event;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Spatie\Snapshots\MatchesSnapshots;

class EventUpdateTest extends TestCase
{
    use RefreshDatabase, MatchesSnapshots, SeedRolesAndPermissions;

    /** @test **/
    public function can_update_an_event(): void
    {
        $event = factory(Event::class)->state('has-team')->create([
            'name' => 'Original Event',
            'slug' => 'Original slug',
        ]);

        $this
            ->actingAsSuperAdmin()
            ->followingRedirects()
            ->post(route('admin.event.update', $event), [
                'name' => 'Updated Event',
                'slug' => 'updated-event',
                'team_id' => $event->team->id,
            ])
            ->assertOk();
        $this->assertEquals(route('admin.event.show', $event), url()->current());

        $updatedEvent = Event::first();
        $this->assertEquals('Updated Event', $updatedEvent->name);
        $this->assertEquals('updated-event', $updatedEvent->slug);
    }
}
